aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/entity_history_entry.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/entity_history_entry.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/entity_history_entry.py19
1 files changed, 8 insertions, 11 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/entity_history_entry.py b/python_openapi_client/fatcat_openapi_client/models/entity_history_entry.py
index e3f18836..14639b1a 100644
--- a/python_openapi_client/fatcat_openapi_client/models/entity_history_entry.py
+++ b/python_openapi_client/fatcat_openapi_client/models/entity_history_entry.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -16,25 +16,22 @@ import re # noqa: F401
import six
-from fatcat_openapi_client.models.changelog_entry import ChangelogEntry # noqa: F401,E501
-from fatcat_openapi_client.models.editgroup import Editgroup # noqa: F401,E501
-from fatcat_openapi_client.models.entity_edit import EntityEdit # noqa: F401,E501
-
class EntityHistoryEntry(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'edit': 'EntityEdit',
'editgroup': 'Editgroup',
'changelog_entry': 'ChangelogEntry'
@@ -47,7 +44,7 @@ class EntityHistoryEntry(object):
}
def __init__(self, edit=None, editgroup=None, changelog_entry=None): # noqa: E501
- """EntityHistoryEntry - a model defined in Swagger""" # noqa: E501
+ """EntityHistoryEntry - a model defined in OpenAPI""" # noqa: E501
self._edit = None
self._editgroup = None
@@ -131,7 +128,7 @@ class EntityHistoryEntry(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -16,25 +16,22 @@ import re # noqa: F401
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name